import type { AspectMain } from '@teambit/aspect';
import { AspectDefinition } from '@teambit/aspect-loader';
import { CacheMain } from '@teambit/cache';
import { CLIMain } from '@teambit/cli';
import type { ComponentMain } from '@teambit/component';
import { ExpressMain } from '@teambit/express';
import type { GraphqlMain } from '@teambit/graphql';
import { SlotRegistry } from '@teambit/harmony';
import { Logger, LoggerMain } from '@teambit/logger';
import { PubsubMain } from '@teambit/pubsub';
import { UIRoot } from './ui-root';
import { UIServer } from './ui-server';
export declare type UIDeps = [PubsubMain, CLIMain, GraphqlMain, ExpressMain, ComponentMain, CacheMain, LoggerMain, AspectMain];
export declare type UIRootRegistry = SlotRegistry<UIRoot>;
export declare type OnStart = () => void;
export declare type OnStartSlot = SlotRegistry<OnStart>;
export declare type UIConfig = {
    port?: number;
    portRange: [number, number];
    host: string;
};
export declare type RuntimeOptions = {
    uiRootName?: string;
    pattern?: string;
    dev?: boolean;
    port?: number;
    rebuild?: boolean;
};
export declare class UiMain {
    private pubsub;
    private config;
    private graphql;
    private uiRootSlot;
    private express;
    private onStartSlot;
    private componentExtension;
    private cache;
    private logger;
    constructor(pubsub: PubsubMain, config: UIConfig, graphql: GraphqlMain, uiRootSlot: UIRootRegistry, express: ExpressMain, onStartSlot: OnStartSlot, componentExtension: ComponentMain, cache: CacheMain, logger: Logger);
    build(uiRootName?: string): Promise<any>;
    createRuntime({ uiRootName, pattern, dev, port, rebuild }: RuntimeOptions): Promise<UIServer>;
    getPort(port?: number): Promise<number>;
    private createUiServerStartedEvent;
    registerOnStart(onStartFn: OnStart): this;
    private invokeOnStart;
    registerUiRoot(uiRoot: UIRoot): void;
    getUi(uiRootName?: string): [string, UIRoot];
    getUiRootOrThrow(uiRootName: string): UIRoot;
    createLink(aspectDefs: AspectDefinition[], rootExtensionName: string): Promise<string>;
    generateRoot(aspectDefs: AspectDefinition[], rootExtensionName: string, runtimeName?: string, rootAspect?: string): Promise<string>;
    private selectPort;
    private buildUiHash;
    private buildIfChanged;
    private buildIfNoBundle;
    private openBrowser;
    static defaultConfig: {
        portRange: number[];
        host: string;
    };
    static runtime: import("@teambit/harmony").RuntimeDefinition;
    static dependencies: import("@teambit/harmony").Aspect[];
    static slots: (((registerFn: () => string) => SlotRegistry<UIRoot>) | ((registerFn: () => string) => SlotRegistry<OnStart>))[];
    static provider([pubsub, cli, graphql, express, componentExtension, cache, loggerMain]: UIDeps, config: any, [uiRootSlot, onStartSlot]: [UIRootRegistry, OnStartSlot]): Promise<UiMain>;
}
